> [!IMPORTANT]
> The documentation has been migrated to the open source [repository pdfdeal-docs](https://github.com/Menghuan1918/pdfdeal-docs), see the [online documentation](https://menghuan1918.github.io/pdfdeal-docs).

If you are looking for documentation on the `V0.1.x` version, please [see here](doc2x_old.md)